@@ -4,11 +4,6 @@
 #include "JSONWorker.h"  //For fetching and parsing and such
 #include "JSONGlobals.h"
 
-#ifdef JSON_UNIT_TEST
-    void internalJSONNode::incinternalAllocCount(void) json_nothrow { JSONNode::incinternalAllocCount(); }
-    void internalJSONNode::decinternalAllocCount(void) json_nothrow { JSONNode::decinternalAllocCount(); }
-#endif
-
 internalJSONNode::internalJSONNode(const internalJSONNode & orig) json_nothrow :
     _type(orig._type), _name(orig._name), _name_encoded(orig._name_encoded),
     _string(orig._string), _string_encoded(orig._string_encoded), _value(orig._value)
@@ -19,7 +14,7 @@ internalJSONNode::internalJSONNode(const internalJSONNode & orig) json_nothrow :
     initializeChildren(0){
 
 
-    incinternalAllocCount();
+    LIBJSON_COPY_CTOR;
     if (isContainer()){
 	   CHILDREN = jsonChildren::newChildren();
 	   if (json_likely(!orig.CHILDREN -> empty())){
@@ -29,19 +24,19 @@ internalJSONNode::internalJSONNode(const internalJSONNode & orig) json_nothrow :
 		  }
 	   }
     }
-    #ifdef JSON_MUTEX_CALLBACKS
+    #ifdef JSON_MUTEX_CALLBACKS /*-> JSON_MUTEX_CALLBACKS */
 	   _set_mutex(orig.mylock, false);
-    #endif
+    #endif /*<- */
 }
 
-#ifdef JSON_PREPARSE
+#ifdef JSON_PREPARSE /*-> JSON_PREPARSE */
     #define SetFetchedFalseOrDo(code) code
-#else
+#else /*<- else */
     #define SetFetchedFalseOrDo(code) SetFetched(false)
-#endif
+#endif /*<- */
 
 //this one is specialized because the root can only be array or node
-#ifdef JSON_READ_PRIORITY
+#ifdef JSON_READ_PRIORITY /*-> JSON_READ_PRIORITY */
 internalJSONNode::internalJSONNode(const json_string & unparsed) json_nothrow : _type(), _name(),_name_encoded(false), _string(unparsed), _string_encoded(), _value()
     initializeMutex(0)
     initializeRefCount(1)
@@ -49,7 +44,7 @@ internalJSONNode::internalJSONNode(const json_string & unparsed) json_nothrow :
     initializeComment(json_global(EMPTY_JSON_STRING))
     initializeChildren(0){
 
-    incinternalAllocCount();
+    LIBJSON_CTOR;
     switch (unparsed[0]){
 	   case JSON_TEXT('{'):  //node
 		  _type = JSON_NODE;
@@ -71,7 +66,7 @@ internalJSONNode::internalJSONNode(const json_string & unparsed) json_nothrow :
     }
 }
 
-#ifndef JSON_STRICT
+#ifndef JSON_STRICT 
     #define LETTERCASE(x, y)\
 	   case JSON_TEXT(x):\
 	   case JSON_TEXT(y)
@@ -80,18 +75,18 @@ internalJSONNode::internalJSONNode(const json_string & unparsed) json_nothrow :
 	   case JSON_TEXT(x)
 #endif
 
-internalJSONNode::internalJSONNode(const json_string & name_t, const json_string & value_t) json_nothrow : _type(), _name_encoded(), _name(JSONWorker::FixString(name_t, NAME_ENCODED)), _string(), _string_encoded(), _value()
+internalJSONNode::internalJSONNode(const json_string & name_t, const json_string & value_t) json_nothrow : _type(), _name(JSONWorker::FixString(name_t, NAME_ENCODED)), _name_encoded(), _string(), _string_encoded(), _value()
     initializeMutex(0)
     initializeRefCount(1)
     initializeFetch(false)
     initializeComment(json_global(EMPTY_JSON_STRING))
     initializeChildren(0){
 
-    incinternalAllocCount();
+    LIBJSON_CTOR;
 
     #ifdef JSON_STRICT
 	   JSON_ASSERT_SAFE(!value_t.empty(), JSON_TEXT("empty node"), Nullify(); return;);
-    #else
+    #else 
 	   if (json_unlikely(value_t.empty())){
 		  _type = JSON_NULL;
 		  SetFetched(true);
@@ -110,53 +105,53 @@ internalJSONNode::internalJSONNode(const json_string & name_t, const json_string
         case JSON_TEXT('\"'):  //a json_string literal, still escaped and with leading and trailing quotes
             JSON_ASSERT_SAFE(lastchar == JSON_TEXT('\"'), JSON_TEXT("Unterminated quote"), Nullify(); return;);
             _type = JSON_STRING;
-		  SetFetchedFalseOrDo(FetchString());
+			SetFetchedFalseOrDo(FetchString());
             break;
         case JSON_TEXT('{'):  //a child node, or set of children
             JSON_ASSERT_SAFE(lastchar == JSON_TEXT('}'), JSON_TEXT("Missing }"), Nullify(); return;);
             _type = JSON_NODE;
-		  CHILDREN = jsonChildren::newChildren();
-		  SetFetchedFalseOrDo(FetchNode());
+			CHILDREN = jsonChildren::newChildren();
+			SetFetchedFalseOrDo(FetchNode());
             break;
         case JSON_TEXT('['):  //an array
             JSON_ASSERT_SAFE(lastchar == JSON_TEXT(']'), JSON_TEXT("Missing ]"), Nullify(); return;);
             _type = JSON_ARRAY;
-		  CHILDREN = jsonChildren::newChildren();
-		  SetFetchedFalseOrDo(FetchArray());
+			CHILDREN = jsonChildren::newChildren();
+			SetFetchedFalseOrDo(FetchArray());
             break;
         LETTERCASE('t', 'T'):
             JSON_ASSERT_SAFE(value_t == json_global(CONST_TRUE), json_string(json_global(ERROR_UNKNOWN_LITERAL) + value_t).c_str(), Nullify(); return;);
             _value._bool = true;
             _type = JSON_BOOL;
-		  SetFetched(true);
+			SetFetched(true);
             break;
         LETTERCASE('f', 'F'):
             JSON_ASSERT_SAFE(value_t == json_global(CONST_FALSE), json_string(json_global(ERROR_UNKNOWN_LITERAL) + value_t).c_str(), Nullify(); return;);
             _value._bool = false;
             _type = JSON_BOOL;
-		  SetFetched(true);
+			SetFetched(true);
             break;
         LETTERCASE('n', 'N'):
             JSON_ASSERT_SAFE(value_t == json_global(CONST_NULL), json_string(json_global(ERROR_UNKNOWN_LITERAL) + value_t).c_str(), Nullify(); return;);
             _type = JSON_NULL;
-		  SetFetched(true);
+			SetFetched(true);
             break;
         default:
             JSON_ASSERT_SAFE(NumberToString::isNumeric(value_t), json_string(json_global(ERROR_UNKNOWN_LITERAL) + value_t).c_str(), Nullify(); return;);
-		  _type = JSON_NUMBER;
-		  SetFetchedFalseOrDo(FetchNumber());
+			_type = JSON_NUMBER;
+			SetFetchedFalseOrDo(FetchNumber());
             break;
     }
 }
 
-#endif
+#endif /*<- */
 
 
 internalJSONNode::~internalJSONNode(void) json_nothrow {
-    decinternalAllocCount();
-    #ifdef JSON_MUTEX_CALLBACKS
+    LIBJSON_DTOR;
+    #ifdef JSON_MUTEX_CALLBACKS 
 	   _unset_mutex();
-    #endif
+    #endif /*<- */
     DELETE_CHILDREN();
 }
 
@@ -168,7 +163,7 @@ internalJSONNode::~internalJSONNode(void) json_nothrow {
 	   _string = JSONWorker::FixString(json_string(_string.begin() + 1, _string.end() - 1), STRING_ENCODED);
 	   #ifdef JSON_LESS_MEMORY
 		  JSON_ASSERT(_string.capacity() == _string.length(), JSON_TEXT("_string object too large 2"));
-	   #endif
+	   #endif 
     }
 
     void internalJSONNode::FetchNode(void) const json_nothrow {
@@ -193,14 +188,14 @@ internalJSONNode::~internalJSONNode(void) json_nothrow {
 void internalJSONNode::FetchNumber(void) const json_nothrow {
     #ifdef JSON_STRICT
 		_value._number = NumberToString::_atof(_string.c_str());
-    #else
+    #else 
 	   #ifdef JSON_UNICODE
 		  const size_t len = _string.length();
-		  #if defined(_MSC_VER) && defined(JSON_SAFE)
+		  #if defined(_MSC_VER) && defined(JSON_SAFE) 
 			 const size_t bytes = (len * (sizeof(json_char) / sizeof(char))) + 1;
 			 json_auto<char> temp(bytes);
 			 size_t res;
-			 errno_t err = std::wcstombs_s(&res, temp.ptr, bytes, _string.c_str(), len);
+			 errno_t err = wcstombs_s(&res, temp.ptr, bytes, _string.c_str(), len);
 			 if (err != 0){
 				_value._number = (json_number)0.0;
 				return;
@@ -213,10 +208,10 @@ void internalJSONNode::FetchNumber(void) const json_nothrow {
 				_value._number = (json_number)0.0;
 				return;
 			 }
-		  #else
+		  #else 
 			 json_auto<char> temp(len + 1);
 			 size_t res = std::wcstombs(temp.ptr, _string.c_str(), len);
-		  #endif
+		  #endif 
 		  temp.ptr[res] = '\0';
 		  _value._number = (json_number)std::atof(temp.ptr);
 	   #else
@@ -248,7 +243,7 @@ void internalJSONNode::FetchNumber(void) const json_nothrow {
 			 default:
 				JSON_FAIL(JSON_TEXT("Fetching an unknown type"));
 				Nullify();
-		  #endif
+		  #endif 
 	   }
 	   fetched = true;
     }
@@ -270,7 +265,7 @@ void internalJSONNode::Set(const json_string & val) json_nothrow {
 	   _value._number = (json_number)val;
 	   #if(defined(JSON_CASTABLE) || !defined(JSON_LESS_MEMORY) || defined(JSON_WRITE_PRIORITY))
 		  _string = NumberToString::_itoa<json_int_t>(val);
-	   #else 
+	   #else
 		  clearString(_string);
 	   #endif
 	   SetFetched(true);
@@ -287,7 +282,7 @@ void internalJSONNode::Set(const json_string & val) json_nothrow {
 	   #endif
 	   SetFetched(true);
     }
-#else
+#else 
     #if(defined(JSON_CASTABLE) || !defined(JSON_LESS_MEMORY) || defined(JSON_WRITE_PRIORITY))
 	   #define SET(converter, type)\
 		  void internalJSONNode::Set(type val) json_nothrow {\
@@ -305,7 +300,7 @@ void internalJSONNode::Set(const json_string & val) json_nothrow {
 			 _string = NumberToString::_ftoa(_value._number);\
 			 SetFetched(true);\
 		  }
-    #else
+    #else /*<- else */
 	   #define SET(converter, type)\
 		  void internalJSONNode::Set(type val) json_nothrow {\
 			 makeNotContainer();\
@@ -329,7 +324,7 @@ void internalJSONNode::Set(const json_string & val) json_nothrow {
     SET_INTEGER(short)
     SET_INTEGER(int)
     SET_INTEGER(long)
-    #ifndef JSON_ISO_STRICT
+    #ifndef JSON_ISO_STRICT 
 	   SET_INTEGER(long long)
 	   SET_FLOAT(long double)
     #endif
@@ -353,10 +348,10 @@ bool internalJSONNode::IsEqualTo(const internalJSONNode * val) const json_nothro
     if (type() != val -> type()) return false;	 //aren't even same type
     if (_name != val -> _name) return false;  //names aren't the same
     if (type() == JSON_NULL) return true;  //both null, can't be different
-    #if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY)
+    #if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY) 
 	   Fetch();
 	   val -> Fetch();
-    #endif
+    #endif 
     switch (type()){
 	   case JSON_STRING:
 		  return val -> _string == _string;
@@ -373,44 +368,44 @@ bool internalJSONNode::IsEqualTo(const internalJSONNode * val) const json_nothro
     JSONNode ** valrunner = val -> CHILDREN -> begin();
     json_foreach(CHILDREN, myrunner){
         JSON_ASSERT(*myrunner != NULL, json_global(ERROR_NULL_IN_CHILDREN));
-	   JSON_ASSERT(*valrunner != NULL, json_global(ERROR_NULL_IN_CHILDREN));
-	   JSON_ASSERT(valrunner != val -> CHILDREN -> end(), JSON_TEXT("at the end of other one's children, but they're the same size?"));
+		JSON_ASSERT(*valrunner != NULL, json_global(ERROR_NULL_IN_CHILDREN));
+		JSON_ASSERT(valrunner != val -> CHILDREN -> end(), JSON_TEXT("at the end of other one's children, but they're the same size?"));
         if (**myrunner != **valrunner) return false;
-	   ++valrunner;
+		++valrunner;
     }
     return true;
 }
 
 void internalJSONNode::Nullify(void) const json_nothrow {
     _type = JSON_NULL;
-    #if(defined(JSON_CASTABLE) || !defined(JSON_LESS_MEMORY) || defined(JSON_WRITE_PRIORITY))
+    #if(defined(JSON_CASTABLE) || !defined(JSON_LESS_MEMORY) || defined(JSON_WRITE_PRIORITY)) /*-> JSON_CASTABLE || !JSON_LESS_MEMORY || JSON_WRITE_PRIORITY */
 	   _string = json_global(CONST_NULL);
-    #else
+    #else /*<- else */
 	   clearString(_string);
-    #endif
+    #endif /*<- */
     SetFetched(true);
 }
 
-#ifdef JSON_MUTEX_CALLBACKS
+#ifdef JSON_MUTEX_CALLBACKS /*-> JSON_MUTEX_CALLBACKS */
     #define JSON_MUTEX_COPY ,mylock
-#else
+#else /*<- else */
     #define JSON_MUTEX_COPY
-#endif
+#endif /*<- */
 
-#ifdef JSON_LIBRARY
+#ifdef JSON_LIBRARY /*-> JSON_LIBRARY */
 void internalJSONNode::push_back(JSONNode * node) json_nothrow {
-#else
+#else /*<- else */
 void internalJSONNode::push_back(const JSONNode & node) json_nothrow {
-#endif
+#endif /*<- */
     JSON_ASSERT_SAFE(isContainer(), json_global(ERROR_NON_CONTAINER) + JSON_TEXT("push_back"), return;);
-    #ifdef JSON_LIBRARY
-	   #ifdef JSON_MUTEX_CALLBACKS
+    #ifdef JSON_LIBRARY /*-> JSON_LIBRARY */
+	   #ifdef JSON_MUTEX_CALLBACKS /*-> JSON_MUTEX_CALLBACKS */
 		  if (mylock != 0) node -> set_mutex(mylock);
-	   #endif
+	   #endif /*<- */
 	   CHILDREN -> push_back(node);
-    #else
+    #else /*<- else */
 	   CHILDREN -> push_back(JSONNode::newJSONNode(node   JSON_MUTEX_COPY));
-    #endif
+    #endif /*<- */
 }
 
 void internalJSONNode::push_front(const JSONNode & node) json_nothrow {
@@ -436,7 +431,7 @@ JSONNode * internalJSONNode::pop_back(const json_string & name_t) json_nothrow {
     return 0;
 }
 
-#ifdef JSON_CASE_INSENSITIVE_FUNCTIONS
+#ifdef JSON_CASE_INSENSITIVE_FUNCTIONS /*-> JSON_CASE_INSENSITIVE_FUNCTIONS */
     JSONNode * internalJSONNode::pop_back_nocase(const json_string & name_t) json_nothrow {
 	   JSON_ASSERT_SAFE(isContainer(), json_global(ERROR_NON_CONTAINER) + JSON_TEXT("pop_back_nocase"), return 0;);
 	   if (JSONNode ** res = at_nocase(name_t)){
@@ -446,7 +441,7 @@ JSONNode * internalJSONNode::pop_back(const json_string & name_t) json_nothrow {
 	   }
 	   return 0;
     }
-#endif
+#endif /*<- */
 
 JSONNode ** internalJSONNode::at(const json_string & name_t) json_nothrow {
     JSON_ASSERT_SAFE(isContainer(), json_global(ERROR_NON_CONTAINER) + JSON_TEXT("at"), return 0;);
@@ -458,7 +453,7 @@ JSONNode ** internalJSONNode::at(const json_string & name_t) json_nothrow {
     return 0;
 }
 
-#ifdef JSON_CASE_INSENSITIVE_FUNCTIONS
+#ifdef JSON_CASE_INSENSITIVE_FUNCTIONS /*-> JSON_CASE_INSENSITIVE_FUNCTIONS */
     bool internalJSONNode::AreEqualNoCase(const json_char * ch_one, const json_char * ch_two) json_nothrow {
 	   while (*ch_one){  //only need to check one, if the other one terminates early, the check will cause it to fail
 		  const json_char c_one = *ch_one;
@@ -488,9 +483,9 @@ JSONNode ** internalJSONNode::at(const json_string & name_t) json_nothrow {
 	   }
 	   return 0;
     }
-#endif
+#endif /*<- */
 
-#if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY)
+#if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY) /*-> JSON_PREPARSE && JSON_READ_PRIORITY */
     void internalJSONNode::preparse(void) json_nothrow {
 	   Fetch();
 	   if (isContainer()){
@@ -499,26 +494,26 @@ JSONNode ** internalJSONNode::at(const json_string & name_t) json_nothrow {
 		  }
 	   }
     }
-#endif
+#endif /*<- */
 
 internalJSONNode::operator bool() const json_nothrow {
     Fetch();
-    #ifdef JSON_CASTABLE
+    #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 	   switch(type()){
 		  case JSON_NUMBER:
 			 return !_floatsAreEqual(_value._number, (json_number)0.0);
 		  case JSON_NULL:
 			 return false;
 	   }
-    #endif
+    #endif /*<- */
     JSON_ASSERT(type() == JSON_BOOL, json_global(ERROR_UNDEFINED) + JSON_TEXT("(bool)"));
     return _value._bool;
 }
 
-#ifdef JSON_LIBRARY
+#ifdef JSON_LIBRARY /*-> JSON_LIBRARY */
     internalJSONNode::operator json_number() const json_nothrow {
 	   Fetch();
-	   #ifdef JSON_CASTABLE
+	   #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 		  switch(type()){
 			 case JSON_NULL:
 				return (json_number)0.0;
@@ -527,14 +522,14 @@ internalJSONNode::operator bool() const json_nothrow {
 			 case JSON_STRING:
 				FetchNumber();
 		  }
-	   #endif
+	   #endif /*<- */
 	   JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("as_float"));
 	   return (json_number)_value._number;
     }
 
     internalJSONNode::operator json_int_t() const json_nothrow {
 	   Fetch();
-	   #ifdef JSON_CASTABLE
+	   #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 		  switch(type()){
 			 case JSON_NULL:
 				return 0;
@@ -543,16 +538,16 @@ internalJSONNode::operator bool() const json_nothrow {
 			 case JSON_STRING:
 				FetchNumber();
 		  }
-	   #endif
+	   #endif /*<- */
 	   JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("as_int"));
 	   JSON_ASSERT(_value._number == (json_number)((json_int_t)_value._number), json_string(JSON_TEXT("as_int will truncate ")) + _string);
 	   return (json_int_t)_value._number;
     }
-#else
-    #ifndef JSON_ISO_STRICT
+#else /*<- else */
+    #ifndef JSON_ISO_STRICT /*-> !JSON_ISO_STRICT */
 	   internalJSONNode::operator long double() const json_nothrow {
 		  Fetch();
-		  #ifdef JSON_CASTABLE
+		  #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 			 switch(type()){
 				case JSON_NULL:
 				    return (long double)0.0;
@@ -561,14 +556,14 @@ internalJSONNode::operator bool() const json_nothrow {
 				case JSON_STRING:
 				    FetchNumber();
 			 }
-		  #endif
+		  #endif /*<- */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(long double)"));
 		  return (long double)_value._number;
 	   }
-    #else
+    #else /*<- else */
 	   internalJSONNode::operator double() const json_nothrow {
 		  Fetch();
-		  #ifdef JSON_CASTABLE
+		  #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 			 switch(type()){
 				case JSON_NULL:
 				    return (double)0.0;
@@ -577,21 +572,21 @@ internalJSONNode::operator bool() const json_nothrow {
 				case JSON_STRING:
 				    FetchNumber();
 			 }
-		  #endif
+		  #endif /*<- */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(double)"));
 		  return (double)_value._number;
 	   }
-    #endif
+    #endif /*<- */
 
     //do whichever one is longer, because it's easy to cast down
-    #ifdef JSON_ISO_STRICT
+    #ifdef JSON_ISO_STRICT /*-> JSON_ISO_STRICT */
 	   internalJSONNode::operator long() const json_nothrow
-    #else
+    #else /*<- else */
 	   internalJSONNode::operator long long() const json_nothrow
-    #endif
+    #endif /*<- */
     {
 	   Fetch();
-	   #ifdef JSON_CASTABLE
+	   #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 		  switch(type()){
 			 case JSON_NULL:
 				return 0;
@@ -600,14 +595,14 @@ internalJSONNode::operator bool() const json_nothrow {
 			 case JSON_STRING:
 				FetchNumber();
 		  }
-	   #endif
-	   #ifdef JSON_ISO_STRICT
+	   #endif /*<- */
+	   #ifdef JSON_ISO_STRICT /*-> JSON_ISO_STRICT */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(long)"));
 		  JSON_ASSERT(_value._number > LONG_MIN, _string + json_global(ERROR_LOWER_RANGE) + JSON_TEXT("long"));
 		  JSON_ASSERT(_value._number < LONG_MAX, _string + json_global(ERROR_UPPER_RANGE) + JSON_TEXT("long"));
 		  JSON_ASSERT(_value._number == (json_number)((long)_value._number), json_string(JSON_TEXT("(long) will truncate ")) + _string);
 		  return (long)_value._number;
-	   #else
+	   #else /*<- else */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(long long)"));
 		  #ifdef LONG_LONG_MAX			 
 			 JSON_ASSERT(_value._number < LONG_LONG_MAX, _string + json_global(ERROR_UPPER_RANGE) + JSON_TEXT("long long"));
@@ -622,17 +617,17 @@ internalJSONNode::operator bool() const json_nothrow {
 
 		  JSON_ASSERT(_value._number == (json_number)((long long)_value._number), json_string(JSON_TEXT("(long long) will truncate ")) + _string);
 		  return (long long)_value._number;
-	   #endif
+	   #endif /*<- */
     }
 
-    #ifdef JSON_ISO_STRICT
+    #ifdef JSON_ISO_STRICT /*-> JSON_ISO_STRICT */
 	   internalJSONNode::operator unsigned long() const json_nothrow
-    #else
+    #else /*<- else */
 	   internalJSONNode::operator unsigned long long() const json_nothrow
-    #endif
+    #endif /*<- */
     {
 	   Fetch();
-	   #ifdef JSON_CASTABLE
+	   #ifdef JSON_CASTABLE /*-> JSON_CASTABLE */
 		  switch(type()){
 			 case JSON_NULL:
 				return 0;
@@ -641,14 +636,14 @@ internalJSONNode::operator bool() const json_nothrow {
 			 case JSON_STRING:
 				FetchNumber();
 		  }
-	   #endif
-	   #ifdef JSON_ISO_STRICT
+	   #endif /*<- */
+	   #ifdef JSON_ISO_STRICT /*-> JSON_ISO_STRICT */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(unsigned long)"));
 		  JSON_ASSERT(_value._number > 0, _string + json_global(ERROR_LOWER_RANGE) + JSON_TEXT("unsigned long"));
 		  JSON_ASSERT(_value._number < ULONG_MAX, _string + json_global(ERROR_UPPER_RANGE) + JSON_TEXT("unsigned long"));
 		  JSON_ASSERT(_value._number == (json_number)((unsigned long)_value._number), json_string(JSON_TEXT("(unsigend long) will truncate ")) + _string);
 		  return (unsigned long)_value._number;
-	   #else
+	   #else /*<- else */
 		  JSON_ASSERT(type() == JSON_NUMBER, json_global(ERROR_UNDEFINED) + JSON_TEXT("(unsigned long long)"));
 		  JSON_ASSERT(_value._number > 0, _string + json_global(ERROR_LOWER_RANGE) + JSON_TEXT("unsigned long long"));
 		  #ifdef ULONG_LONG_MAX
@@ -658,76 +653,76 @@ internalJSONNode::operator bool() const json_nothrow {
 		  #endif
 		  JSON_ASSERT(_value._number == (json_number)((unsigned long long)_value._number), json_string(JSON_TEXT("(unsigned long long) will truncate ")) + _string);
 		  return (unsigned long long)_value._number;
-	   #endif
+	   #endif /*<- */
     }
-#endif
+#endif /*<- */
 	
 	/*
 	 These functions are to allow allocation to be completely controlled by the callbacks
 	 */
 	
-#ifdef JSON_MEMORY_POOL
+#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 	#include "JSONMemoryPool.h"
 	static memory_pool<INTERNALNODEPOOL> json_internal_mempool;
-#endif
+#endif /*<- */
 	
 void internalJSONNode::deleteInternal(internalJSONNode * ptr) json_nothrow {
-	#ifdef JSON_MEMORY_POOL
+	#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 		ptr -> ~internalJSONNode();
 		json_internal_mempool.deallocate((void*)ptr);
-	#elif defined(JSON_MEMORY_CALLBACKS)
+	#elif defined(JSON_MEMORY_CALLBACKS) /*<- else JSON_MEMORY_CALLBACKS */
 		ptr -> ~internalJSONNode();
 		libjson_free<internalJSONNode>(ptr);
-	#else
+	#else /*<- else */
 		delete ptr;
-	#endif
+	#endif /*<- */
 }
 	
 internalJSONNode * internalJSONNode::newInternal(char mytype) {
-	#ifdef JSON_MEMORY_POOL
+	#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 		return new((internalJSONNode*)json_internal_mempool.allocate()) internalJSONNode(mytype);
-	#elif defined(JSON_MEMORY_CALLBACKS)
+	#elif defined(JSON_MEMORY_CALLBACKS) /*<- else JSON_MEMORY_CALLBACKS */
 		return new(json_malloc<internalJSONNode>(1)) internalJSONNode(mytype);
-	#else
+	#else /*<- else */
 		return new internalJSONNode(mytype);
-	#endif
+	#endif /*<- */
 }
 	
-#ifdef JSON_READ_PRIORITY
+#ifdef JSON_READ_PRIORITY /*-> JSON_READ_PRIORITY */
 internalJSONNode * internalJSONNode::newInternal(const json_string & unparsed) {
-	#ifdef JSON_MEMORY_POOL
+	#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 		return new((internalJSONNode*)json_internal_mempool.allocate()) internalJSONNode(unparsed);
-	#elif defined(JSON_MEMORY_CALLBACKS)
+	#elif defined(JSON_MEMORY_CALLBACKS) /*<- else JSON_MEMORY_CALLBACKS */
 		return new(json_malloc<internalJSONNode>(1)) internalJSONNode(unparsed);
-	#else
+	#else /*<- else */
 		return new internalJSONNode(unparsed);
-	#endif
+	#endif /*<- */
 }
 	
 internalJSONNode * internalJSONNode::newInternal(const json_string & name_t, const json_string & value_t) {
-	#ifdef JSON_MEMORY_POOL
+	#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 		return new((internalJSONNode*)json_internal_mempool.allocate()) internalJSONNode(name_t, value_t);
-	#elif defined(JSON_MEMORY_CALLBACKS)
+	#elif defined(JSON_MEMORY_CALLBACKS) /*<- else JSON_MEMORY_CALLBACKS */
 		return new(json_malloc<internalJSONNode>(1)) internalJSONNode(name_t, value_t);
-	#else
+	#else /*<- else */
 		return new internalJSONNode(name_t, value_t);
-	#endif
+	#endif /*<- */
 }
 	
-#endif
+#endif /*<- */
 	
 internalJSONNode * internalJSONNode::newInternal(const internalJSONNode & orig) {
-	#ifdef JSON_MEMORY_POOL
+	#ifdef JSON_MEMORY_POOL /*-> JSON_MEMORY_POOL */
 		return new((internalJSONNode*)json_internal_mempool.allocate()) internalJSONNode(orig);
-	#elif defined(JSON_MEMORY_CALLBACKS)
+	#elif defined(JSON_MEMORY_CALLBACKS) /*<- else JSON_MEMORY_CALLBACKS */
 		return new(json_malloc<internalJSONNode>(1)) internalJSONNode(orig);
-	#else
+	#else /*<- else */
 		return new internalJSONNode(orig);
-	#endif
+	#endif /*<- */
 }
 
-#ifdef JSON_DEBUG
-    #ifndef JSON_LIBRARY
+#ifdef JSON_DEBUG /*-> JSON_MEMORY_POOL */
+    #ifndef JSON_LIBRARY /*-> JSON_MEMORY_POOL */
 	   JSONNode internalJSONNode::Dump(size_t & totalbytes) const json_nothrow {
 		  JSONNode dumpage(JSON_NODE);
 		  dumpage.set_name(JSON_TEXT("internalJSONNode"));
@@ -741,20 +736,20 @@ internalJSONNode * internalJSONNode::newInternal(const internalJSONNode & orig)
 				memory += sizeof(jsonChildren);
 				memory += CHILDREN -> capacity() * sizeof(JSONNode*);
 			 }
-			 #ifdef JSON_COMMENTS
+			 #ifdef JSON_COMMENTS /*-> JSON_COMMENTS */
 				memory += _comment.capacity() * sizeof(json_char);
-			 #endif
+			 #endif /*<- */
 			 totalbytes += memory;
 			 dumpage.push_back(JSON_NEW(JSONNode(JSON_TEXT("bytes used"), memory)));
 		  END_MEM_SCOPE
 
 
-		  #ifdef JSON_REF_COUNT
+		  #ifdef JSON_REF_COUNT /*-> JSON_REF_COUNT */
 			 dumpage.push_back(JSON_NEW(JSONNode(JSON_TEXT("refcount"), refcount)));
-		  #endif
-		  #ifdef JSON_MUTEX_CALLBACKS
+		  #endif /*<- */
+		  #ifdef JSON_MUTEX_CALLBACKS /*-> JSON_MUTEX_CALLBACKS */
 			 dumpage.push_back(JSON_NEW(DumpMutex()));
-		  #endif
+		  #endif /*<- */
 
 
 		  #define DUMPCASE(ty)\
@@ -800,18 +795,18 @@ internalJSONNode * internalJSONNode::newInternal(const internalJSONNode & orig)
 			 dumpage.push_back(JSON_NEW(unio));
 		  }
 
-		  #if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY)
+		  #if !defined(JSON_PREPARSE) && defined(JSON_READ_PRIORITY) /*-> !JSON_PREPARSE && JSON_READ_PRIORITY */
 			 dumpage.push_back(JSON_NEW(JSONNode(JSON_TEXT("fetched"), fetched)));
-		  #endif
+		  #endif /*<- */
 
-		  #ifdef JSON_COMMENTS
+		  #ifdef JSON_COMMENTS /*-> JSON_COMMENTS */
 			 str.clear();
 			 str.set_name(JSON_TEXT("_comment"));
 			 str.push_back(JSON_NEW(JSONNode(JSON_TEXT("value"), _comment)));
 			 str.push_back(JSON_NEW(JSONNode(JSON_TEXT("length"), _comment.length())));
 			 str.push_back(JSON_NEW(JSONNode(JSON_TEXT("capactiy"), _comment.capacity())));
 			 dumpage.push_back(JSON_NEW(str));
-		  #endif
+		  #endif /*<- */
 
 		  if (isContainer()){
 			 JSONNode arra(JSON_NODE);
@@ -829,5 +824,5 @@ internalJSONNode * internalJSONNode::newInternal(const internalJSONNode & orig)
 
 		  return dumpage;
 	   }
-    #endif
-#endif
+    #endif /*<- */
+#endif /*<- */
